#####################################################################
# Copyright (C) 2000 Artur Trzewik
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
######################################################################
# Header
# CVS - $Id: preferences.tcl,v 1.6 2000/10/20 09:44:20 artur Exp $
#
# Information:
# Modul
# setzt das lan globale Varible mit Sprachspzifischen Zeichenketten
# die aus *.lan Dateien ausgelesen werden
# Behandelt auch die Programm Optionnen in Datein ~/.xdobry

proc setlanguage language {
    global lan progdir
    set lanfile [open [file join $progdir ${language}.lan] r]
    set lan_doc [dom parse [read $lanfile]]
    close $lanfile
    set lan_dom [$lan_doc documentElement]
    foreach catalog [$lan_dom selectNodes child::catalog] {
	readcatalog $catalog [$catalog getAttribute name]
    }
    $lan_doc delete
}
proc readcatalog {node key} {
    foreach catalog [$node selectNodes child::catalog] {
	readcatalog $catalog $key.[$catalog getAttribute name]
    }
    global lan
    foreach string [$node selectNodes child::string] {
	set lan($key.[$string getAttribute name]) [$string text]
    }
}
proc checklanguage {ext} {
    global option progdir
    if {$option(language)=="dummy"} {
	# buid checklanguage window
	set lanl {{type OComboBox} {name language} {label Language} }
	# Finde alle erreichbare *_.lan Dateien 
	# z.B englisch_fs.lan german_fs.lan
	set lan_files [glob [file join $progdir *_$ext.lan]]
	
	foreach lfile $lan_files {
	    regexp (.+)_$ext.lan [file tail $lfile] _ lan
	    lappend lans $lan
	}
	keylset lanl valuelist $lans
	set checkl {{type OCheckButton} {name forever} {label {use for next sesions}}}
	    
	OInputDialog landialog [list $lanl $checkl] {{language german}}  -message {Choose the Language for the session} -type ok -returnChanges 0
	if {[set ret [landialog execute]]!=""} {
	    set option(language) [keylget ret language]
	    if {[keylget ret forever]} {
		savepref
	    }
	}
	landialog destroy
    }
    setlanguage "$option(language)_$ext"
    # !!! Vorsicht beim nderungen
    if {$option(language)!="german"} {
	global helpdir
	append helpdir _en
    }
}

proc defaultpref {{var option}} {
    global $var
    array set $var {
	language dummy
	htmlhelpviewer {netscape %s}
	netscape_remote 1
    }
}
proc loadpref {} {
    global option tcl_platform
    defaultpref
    if {$tcl_platform(platform)=="windows"} {
    	if {![catch {package require registry}]} {
	    set reg_path {HKEY_CURRENT_USER\Software\xdobry}
	    if {![catch {set values [registry values $reg_path]}]} {
         	foreach val $values {
		    set option($val) [registry get $reg_path $val]
		}
	}
      }
    } else {
    	if {[file exists [file join ~  .xdobry]]} {
	    set preffile [open [file join ~ .xdobry] r]
	    while {[gets $preffile Zeile] >= 0} {
		set option([lindex $Zeile 0]) [lindex $Zeile 1]
	    }
	}
    }
}
proc savepref {} {
    global option lan errorInfo tcl_platform
    if {$tcl_platform(platform)=="windows"} {
    	if {![catch {package require registry}]} {
      	set reg_path {HKEY_CURRENT_USER\Software\xdobry}
	      set indicator [array startsearch option]
    		while {[array anymore option $indicator]} {
				set elem [array nextelement option $indicator]
  				registry set $reg_path $elem $option($elem)
    		}
      }
    } else {
     set ret [catch { set preffile [open [file join ~ .xdobry] w] }]
    if {$ret != 0} {
	tk_messageBox -title Error -message "$lan(message.csprefmessage) $errorInfo"  -icon error -type ok
	return
    }
    set indicator [array startsearch option]
    while {[array anymore option $indicator]} {
	set elem [array nextelement option $indicator]
	puts $preffile "$elem [list $option($elem)]"
    }
    close $preffile
    }
}

